<?php

namespace Drupal\openquestions\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the oq application entity type.
 */
class OqApplicationAccessControlHandler extends EntityAccessControlHandler {

	/**
	 * {@inheritdoc}
	 */
	protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

		switch ($operation) {
			case 'view':
				return AccessResult::allowedIfHasPermission($account, 'view oq application');

			case 'update':
				return AccessResult::allowedIfHasPermissions(
					$account,
					['edit oq application', 'administer oq application'],
					'OR',
				);

			case 'delete':
				return AccessResult::allowedIfHasPermissions(
					$account,
					['delete oq application', 'administer oq application'],
					'OR',
				);

			default:
				// No opinion.
				return AccessResult::neutral();
		}

	}

	/**
	 * {@inheritdoc}
	 */
	protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
		return AccessResult::allowedIfHasPermissions(
			$account,
			['create oq application', 'administer oq application'],
			'OR',
		);
	}

}
