<?php

namespace Drupal\openquestions\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the oq item entity type.
 */
class OqItemAccessControlHandler extends EntityAccessControlHandler {

	/**
	 * {@inheritdoc}
	 */
	protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

		switch ($operation) {
			case 'view':
				return AccessResult::allowedIfHasPermission($account, 'view oq item');

			case 'update':
				return AccessResult::allowedIfHasPermissions(
					$account,
					['edit oq item', 'administer oq item'],
					'OR',
				);

			case 'delete':
				return AccessResult::allowedIfHasPermissions(
					$account,
					['delete oq item', 'administer oq item'],
					'OR',
				);

			default:
				// No opinion.
				return AccessResult::neutral();
		}

	}

	/**
	 * {@inheritdoc}
	 */
	protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
		return AccessResult::allowedIfHasPermissions(
			$account,
			['create oq item', 'administer oq item'],
			'OR',
		);
	}

}
