<?php

namespace Drupal\openquestions\ContextProvider;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Plugin\Context\Context;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\Core\Plugin\Context\EntityContext;
use Drupal\Core\Plugin\Context\EntityContextDefinition;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\openquestions\Entity\Term;

/**
 * Sets the current oq_item as a context on oq_item routes.
 */
class OQItemRouteContext implements ContextProviderInterface {

	use StringTranslationTrait;

	/**
	 * The route match object.
	 *
	 * @var \Drupal\Core\Routing\RouteMatchInterface
	 */
	protected $routeMatch;

	/**
	 * Constructs a new OQItemRouteContext.
	 *
	 * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
	 *	 The route match object.
	 */
	public function __construct(RouteMatchInterface $route_match) {
		$this->routeMatch = $route_match;
	}

	/**
	 * {@inheritdoc}
	 */
	public function getRuntimeContexts(array $unqualified_context_ids) {
		$result = [];
		$context_definition = EntityContextDefinition::create('oq_item')->setRequired(FALSE);
		$value = NULL;
		if ($route_object = $this->routeMatch->getRouteObject()) {
			$route_parameters = $route_object->getOption('parameters');

			if (isset($route_parameters['oq_item']) && $oq_item = $this->routeMatch->getParameter('oq_item')) {
				$value = $oq_item;
			}
		}

		$cacheability = new CacheableMetadata();
		$cacheability->setCacheContexts(['route']);

		$context = new Context($context_definition, $value);
		$context->addCacheableDependency($cacheability);
		$result['oq_item'] = $context;

		return $result;
	}

	/**
	 * {@inheritdoc}
	 */
	public function getAvailableContexts() {
		$context = EntityContext::fromEntityTypeId('oq_item', $this->t('OQ Item from URL'));
		return ['oq_item' => $context];
	}

}
